#####################################
FitBenchmarking Concept Documentation
#####################################

Here we outline why we built the fitbenchmarking software, and how the software
benchmarks minimizers with the goal of hightlighting the best tool for different
types of data.

.. toctree::
    :titlesonly:
    :caption: Contents:

    why
    how
